-- STEP 1

create table #DBspace (
						DBName sysname, 
						CompatibilityLevel int,
						Collation nvarchar(40),
						DBSize nvarchar(20), 
						Unallocated nvarchar(20), 
						DataSize nvarchar(20), 
						LogSize nvarchar(20), 
						IndexSize nvarchar(20), 
						Unused nvarchar(20))
GO

--insert into #DBSpace (ID, DBName) Select database_id, name from sys.databases

execute sp_msforeachdb '
USE [?];
Declare @dbsize float
Declare @logsize float
Declare @reservedpages float
Declare @usedpages float
Declare @pages float
Declare @database_name sysname
Declare @database_size nvarchar(20)
Declare @log_size nvarchar(20)
Declare @unallocated_space nvarchar(20)
Declare @reserved nvarchar(20)
Declare @data nvarchar(20)
Declare @unused nvarchar(20)
Declare @index_size nvarchar(20)

select	@dbsize = sum(convert(bigint,case when status & 64 = 0 then size else 0 end)),
		@logsize = sum(convert(bigint,case when status & 64 <> 0 then size else 0 end))
from dbo.sysfiles

Select	@reservedpages = sum(a.total_pages),
		@usedpages = sum(a.used_pages),
		@pages = sum(
					CASE
						When it.internal_type IN (202,204) Then 0
						When a.type <> 1 Then a.used_pages
						When p.index_id < 2 Then a.data_pages
						Else 0
					END
		)
from 
		sys.partitions p join sys.allocation_units a on p.partition_id = a.container_id
		left join sys.internal_tables it on p.object_id = it.object_id

select 
		@database_name = db_name(),
		@database_size = ltrim(str((convert (dec (15,2),@dbsize) + convert (dec (15,2),@logsize)) * 8192 / 1048576,15,2) + '' MB''),
		@unallocated_space = ltrim(str((case when @dbsize >= @reservedpages then	(convert (dec (15,2),@dbsize) - convert (dec (15,2),@reservedpages)) * 8192 / 1048576 else 0 end),15,2) + '' MB''),
		@log_size = ltrim(str(convert (dec (15,2),@logsize) * 8192 / 1048576,15,2) + '' MB'')

select
		@reserved = ltrim(str(@reservedpages * 8192 / 1048576,15,2) + '' MB''),
		@data = ltrim(str(@pages * 8192 / 1048576,15,2) + '' MB''),
		@index_size = ltrim(str((@usedpages - @pages) * 8192 / 1048576,15,2) + '' MB''),
		@unused = ltrim(str((@reservedpages - @usedpages) * 8192 / 1048576,15,2) + '' MB'')

Insert into #DBspace (DBName, DBSize, Unallocated, DataSize, LogSize, IndexSize, Unused)
values (@database_name, @database_size, @unallocated_space, @data, @log_size, @index_size, @unused)
'



Update #DBspace
Set		collation = collation_name,
		compatibilityLevel = compatibility_level
from	#DBspace inner join sys.databases
on		#DBspace.DBName = sys.databases.name;

Select * from #DBSpace


-- STEP 2
			
--drop table #dbspace